@@ -89,6 +89,7 @@
 #define ENV_DEFAULT_CRL_DAYS 	"default_crl_days"
 #define ENV_DEFAULT_CRL_HOURS 	"default_crl_hours"
 #define ENV_DEFAULT_MD		"default_md"
+#define ENV_PRESERVE		"preserve"
 #define ENV_POLICY      	"policy"
 
 #define ENV_DATABASE		"database"
@@ -125,6 +126,7 @@ static char *ca_usage[]={
 " -outdir dir     - Where to put output certificates\n",
 " -infiles ....   - The last argument, requests to process\n",
 " -spkac file     - File contains DN and signed public key and challenge\n",
+" -preserveDN     - Don't re-order the DN\n",
 NULL
 };
 
@@ -170,6 +172,8 @@ static LHASH *conf;
 static char *key=NULL;
 static char *section=NULL;
 
+static int preserve=0;
+
 int MAIN(argc, argv)
 int argc;
 char **argv;
@@ -207,18 +211,20 @@ char **argv;
 	X509_CRL *crl=NULL;
 	X509_CRL_INFO *ci=NULL;
 	X509_REVOKED *r=NULL;
-	char **pp,*p,*f;
-	int i,j,k,n,m;
+	char **pp,*f;
+	int i,j;
 	long l;
 	EVP_MD *dgst=NULL;
 	STACK *attribs=NULL;
 	STACK *cert_sk=NULL;
+	BIO *hex=NULL;
 #undef BSIZE
 #define BSIZE 256
-	char buf[3][BSIZE];
+	MS_STATIC char buf[3][BSIZE];
 
 	apps_startup();
 
+	preserve=0;
 	if (bio_err == NULL)
 		if ((bio_err=BIO_new(BIO_s_file())) != NULL)
 			BIO_set_fp(bio_err,stderr,BIO_NOCLOSE);
@@ -287,6 +293,8 @@ char **argv;
 			}
 		else if (strcmp(*argv,"-batch") == 0)
 			batch=1;
+		else if (strcmp(*argv,"-preserveDN") == 0)
+			preserve=1;
 		else if (strcmp(*argv,"-gencrl") == 0)
 			gencrl=1;
 		else if (strcmp(*argv,"-crldays") == 0)
@@ -424,6 +432,10 @@ bad:
 		goto err;
 		}
 
+	f=CONF_get_string(conf,BASE_SECTION,ENV_PRESERVE);
+	if ((f != NULL) && ((*f == 'y') || (*f == 'Y')))
+		preserve=1;
+
 	/*****************************************************************/
 	/* lookup where to write new certificates */
 	if ((outdir == NULL) && (req))
@@ -541,6 +553,21 @@ bad:
 		}
 
 	/*****************************************************************/
+	if (req || gencrl)
+		{
+		if (outfile != NULL)
+			{
+
+			if (BIO_write_filename(Sout,outfile) <= 0)
+				{
+				perror(outfile);
+				goto err;
+				}
+			}
+		else
+			BIO_set_fp(Sout,stdout,BIO_NOCLOSE);
+		}
+
 	if (req)
 		{
 		if ((md == NULL) && ((md=CONF_get_string(conf,
@@ -593,7 +620,7 @@ bad:
 			{
 			if ((f=BN_bn2ascii(serial)) == NULL) goto err;
 			fprintf(stderr,"next serial number is %s\n",f);
-			free(f);
+			Free(f);
 			}
 
 		if ((attribs=CONF_get_section(conf,policy)) == NULL)
@@ -602,21 +629,9 @@ bad:
 			goto err;
 			}
 
-		if (outfile != NULL)
-			{
-
-			if (BIO_write_filename(Sout,outfile) <= 0)
-				{
-				perror(outfile);
-				goto err;
-				}
-			}
-		else
-			BIO_set_fp(Sout,stdout,BIO_NOCLOSE);
-
 		if ((cert_sk=sk_new_null()) == NULL)
 			{
-			fprintf(stderr,"malloc failure\n");
+			fprintf(stderr,"Malloc failure\n");
 			goto err;
 			}
 		if (spkac_file != NULL)
@@ -632,7 +647,7 @@ bad:
 				if (!BN_add_word(serial,1)) goto err;
 				if (!sk_push(cert_sk,(char *)x))
 					{
-					fprintf(stderr,"malloc failure\n");
+					fprintf(stderr,"Malloc failure\n");
 					goto err;
 					}
 				if (outfile)
@@ -655,7 +670,7 @@ bad:
 				if (!BN_add_word(serial,1)) goto err;
 				if (!sk_push(cert_sk,(char *)x))
 					{
-					fprintf(stderr,"malloc failure\n");
+					fprintf(stderr,"Malloc failure\n");
 					goto err;
 					}
 				}
@@ -673,7 +688,7 @@ bad:
 				if (!BN_add_word(serial,1)) goto err;
 				if (!sk_push(cert_sk,(char *)x))
 					{
-					fprintf(stderr,"malloc failure\n");
+					fprintf(stderr,"Malloc failure\n");
 					goto err;
 					}
 				}
@@ -810,6 +825,8 @@ bad:
 		{
 		EVP_PKEY pkey;
 
+		if ((hex=BIO_new(BIO_s_mem())) == NULL) goto err;
+
 		if (!crldays && !crlhours)
 			{
 			crldays=CONF_get_number(conf,section,
@@ -840,33 +857,13 @@ bad:
 				{
 				if ((r=X509_REVOKED_new()) == NULL) goto err;
 				strcpy(r->revocationDate,pp[DB_rev_date]);
-				j=(int)strlen(pp[DB_serial])/2;
-				if ((p=(char *)malloc(j+1)) == NULL)
-					{
-					fprintf(stderr,"malloc failure\n");
+
+				BIO_reset(hex);
+				if (!BIO_puts(hex,pp[DB_serial]))
 					goto err;
-					}
-				r->serialNumber->length=j;
-				r->serialNumber->data=(unsigned char *)p;
-				f=pp[DB_serial];
-				for (; j; j--)
-					{
-					m=0;
-					for (k=0; k<2; k++)
-						{
-						n= *(f++);
-						if ((n >= '0') && (n <= '9'))
-							n-='0';
-						else if ((n >= 'a')
-							&& (n <= 'z'))
-							n=n-'a'+10;
-						else if ((n >= 'A')
-							&& (n <= 'Z'))
-							n=n-'A'+10;
-						m=(m<<4)|n;
-						}
-					*(p++)=m;
-					}
+				if (!a2i_ASN1_INTEGER(hex,r->serialNumber,
+					buf[0],BSIZE)) goto err;
+
 				sk_push(ci->revoked,(char *)r);
 				}
 			}
@@ -900,6 +897,7 @@ bad:
 	/*****************************************************************/
 	ret=0;
 err:
+	if (hex != NULL) BIO_free(hex);
 	if (Cout != NULL) BIO_free(Cout);
 	if (Sout != NULL) BIO_free(Sout);
 	if (out != NULL) BIO_free(out);
@@ -1205,7 +1203,7 @@ X509_REQ *req;
 	/* Ok, now we check the 'policy' stuff. */
 	if ((subject=sk_new_null()) == NULL)
 		{
-		fprintf(stderr,"malloc failure\n");
+		fprintf(stderr,"Malloc failure\n");
 		goto err;
 		}
 
@@ -1282,7 +1280,7 @@ X509_REQ *req;
 				{
 				if (push != NULL)
 					X509_NAME_ENTRY_free(push);
-				fprintf(stderr,"malloc failure\n");
+				fprintf(stderr,"Malloc failure\n");
 				goto err;
 				}
 			}
@@ -1296,6 +1294,12 @@ X509_REQ *req;
 		ne->set=i;
 		}
 
+	if (preserve)
+		{
+		X509_NAME_free(subject);
+		subject=X509_NAME_dup(req->req_info->subject);
+		}
+
 	if (verbose)
 		fprintf(stderr,"The subject name apears to be ok, checking data base for clashes\n");
 
@@ -1303,7 +1307,7 @@ X509_REQ *req;
 	row[DB_serial]=BN_bn2ascii(serial);
 	if ((row[DB_name] == NULL) || (row[DB_serial] == NULL))
 		{
-		fprintf(stderr,"malloc failure\n");
+		fprintf(stderr,"Malloc failure\n");
 		goto err;
 		}
 
@@ -1410,26 +1414,26 @@ X509_REQ *req;
 		goto err;
 
 	/* We now just add it to the database */
-	row[DB_type]=(char *)malloc(2);
+	row[DB_type]=(char *)Malloc(2);
 	row[DB_exp_date]=(char *)ASN1_UTCTIME_dup(ci->validity->notAfter);
 	row[DB_rev_date]=NULL;
 	/* row[DB_serial] done already */
-	row[DB_file]=(char *)malloc(8);
+	row[DB_file]=(char *)Malloc(8);
 	/* row[DB_name] done already */
 
 	if ((row[DB_type] == NULL) || (row[DB_exp_date] == NULL) ||
 		(row[DB_file] == NULL))
 		{
-		fprintf(stderr,"malloc failure\n");
+		fprintf(stderr,"Malloc failure\n");
 		goto err;
 		}
 	strcpy(row[DB_file],"unknown");
 	row[DB_type][0]='V';
 	row[DB_type][1]='\0';
 
-	if ((irow=(char **)malloc(sizeof(char *)*(DB_NUMBER+1))) == NULL)
+	if ((irow=(char **)Malloc(sizeof(char *)*(DB_NUMBER+1))) == NULL)
 		{
-		fprintf(stderr,"malloc failure\n");
+		fprintf(stderr,"Malloc failure\n");
 		goto err;
 		}
 
@@ -1449,7 +1453,7 @@ X509_REQ *req;
 	ok=1;
 err:
 	for (i=0; i<DB_NUMBER; i++)
-		if (row[i] != NULL) free(row[i]);
+		if (row[i] != NULL) Free(row[i]);
 
 	if (CAname != NULL)
 		X509_NAME_free(CAname);
@@ -1494,11 +1498,11 @@ int output_der;
 	f=X509_NAME_oneline(X509_get_issuer_name(x));
 	BIO_puts(bp,"issuer :");
 	BIO_puts(bp,f);
-	BIO_puts(bp,"\n"); free(f);
+	BIO_puts(bp,"\n"); Free(f);
 	f=X509_NAME_oneline(X509_get_subject_name(x));
 	BIO_puts(bp,"subject:");
 	BIO_puts(bp,f);
-	BIO_puts(bp,"\n"); free(f);
+	BIO_puts(bp,"\n"); Free(f);
 	BIO_puts(bp,"serial :");
 	i2a_ASN1_INTEGER(bp,x->cert_info->serialNumber);
 	BIO_puts(bp,"\n\n");
@@ -1588,10 +1592,11 @@ int verbose;
 			{
 			if (strcmp(type, "SPKAC") == 0)
 				{
-				spki_der = malloc(strlen(cv->value) + 1);
+				spki_der=(unsigned char *)Malloc(
+					strlen(cv->value)+1);
 				if (spki_der == NULL)
 					{
-					fprintf(stderr,"malloc failure\n");
+					fprintf(stderr,"Malloc failure\n");
 					goto err;
 					}
 				j = EVP_DecodeBlock(spki_der, (unsigned char *)cv->value,
@@ -1604,7 +1609,7 @@ int verbose;
 
 				p=spki_der;
 				spki = d2i_NETSCAPE_SPKI(&spki, &p, j);
-				free(spki_der);
+				Free(spki_der);
 				spki_der = NULL;
 				if (spki == NULL)
 					{
@@ -1636,9 +1641,9 @@ int verbose;
 
 		j = strlen(cv->value);
 		ne->value->length=j;
-		ne->value->data=(unsigned char *)malloc(j+1);
+		ne->value->data=(unsigned char *)Malloc(j+1);
 		if (ne->value->data == NULL)
-			{ fprintf(stderr,"malloc failure\n"); goto err; }
+			{ fprintf(stderr,"Malloc failure\n"); goto err; }
 		memcpy(ne->value->data,cv->value,j+1);
 		if (!sk_push(n,(char *)ne)) goto err;
 		ne=NULL;
@@ -1683,7 +1688,7 @@ int verbose;
 err:
 	if (req != NULL) X509_REQ_free(req);
 	if (parms != NULL) CONF_free(parms);
-	if (spki_der != NULL) free(spki_der);
+	if (spki_der != NULL) Free(spki_der);
 	if (spki != NULL) NETSCAPE_SPKI_free(spki);
 	if (ne != NULL) X509_NAME_ENTRY_free(ne);
 
