@@ -85,7 +85,7 @@ char **argv;
 
 	apps_startup();
 
-	if ((buf=(unsigned char *)malloc(BUFSIZE)) == NULL)
+	if ((buf=(unsigned char *)Malloc(BUFSIZE)) == NULL)
 		{
 		fprintf(stderr,"out of memory\n");
 		goto end;
@@ -181,7 +181,7 @@ end:
 	if (buf != NULL)
 		{
 		memset(buf,0,BUFSIZE);
-		free(buf);
+		Free(buf);
 		}
 	if (in != NULL) BIO_free(in);
 	if (bmd != NULL) BIO_free(bmd);
