@@ -238,13 +238,13 @@ bad:
 				a=X509_NAME_oneline(X509_get_subject_name(x));
 				BIO_puts(out,"subject=");
 				BIO_puts(out,a);
-				free(a);
+				Free(a);
 
 				a=X509_NAME_oneline(X509_get_issuer_name(x));
 				BIO_puts(out,"\nissuer= ");
 				BIO_puts(out,a);
 				BIO_puts(out,"\n");
-				free(a);
+				Free(a);
 
 				PEM_write_bio_X509(out,x);
 				BIO_puts(out,"\n");
@@ -262,7 +262,7 @@ bad:
 				a=X509_NAME_oneline(crl->crl->issuer);
 				BIO_puts(out,"issuer= ");
 				BIO_puts(out,a);
-				free(a);
+				Free(a);
 
 				BIO_puts(out,"\nlast update=");
 				ASN1_UTCTIME_print(out,crl->crl->lastUpdate);
