@@ -82,11 +82,11 @@ EIO_HANDLE *hdl;
 		hp=ctx->handlers;
 		if (hp == NULL)
 			{
-			hp=(EIO_HANDLE **)malloc(i*sizeof(EIO_HANDLE *));
+			hp=(EIO_HANDLE **)Malloc(i*sizeof(EIO_HANDLE *));
 			}
 		else
 			{
-			hp=(EIO_HANDLE **)realloc(hp,i*sizeof(EIO_HANDLE *));
+			hp=(EIO_HANDLE **)Realloc(hp,i*sizeof(EIO_HANDLE *));
 			if (hp == NULL) return(0);
 			}
 		for (j=ctx->num_handlers; j<i; j++)
@@ -166,7 +166,7 @@ EIO_HANDLE *EIO_HANDLE_new()
 	{
 	EIO_HANDLE *ret;
 
-	ret=(EIO_HANDLE *)malloc(sizeof(EIO_HANDLE));
+	ret=(EIO_HANDLE *)Malloc(sizeof(EIO_HANDLE));
 	ret->ctx=NULL;
 	ret->fd=0;
 	ret->state=0;
@@ -177,10 +177,13 @@ EIO_HANDLE *EIO_HANDLE_new()
 	return(ret);
 	}
 
-void EIO_HANDLE_free(a)
+void EIO_HANDLE_free(a,func)
 EIO_HANDLE *a;
+void (*func)();
 	{
-	free((char *)a);
+	if ((a->data != NULL) && (func != NULL))
+		func(a->data);
+	Free((char *)a);
 	}
 
 void EIO_CTX_free(a,cb)
@@ -195,12 +198,10 @@ void (*cb)();
 	for (i=0; i<a->num_handlers; i++)
 		{
 		if (hpp[i] != NULL)
-			{
-			if (cb != NULL) cb(hpp[i]->data);
-			EIO_HANDLE_free(hpp[i]);
-			}
+			EIO_HANDLE_free(hpp[i],cb);
 		}
-	free((char *)a->handlers);
+	Free((char *)a->handlers);
+	Free((char *)a);
 	}
 
 #ifdef WINDOWS
@@ -246,7 +247,7 @@ EIO_CTX *EIO_CTX_new()
 	{
 	EIO_CTX *ret;
 
-	ret=(EIO_CTX *)malloc(sizeof(EIO_CTX));
+	ret=(EIO_CTX *)Malloc(sizeof(EIO_CTX));
 	ret->max_fd=0;
 #ifdef WINDOWS
 	if (!mesgwin_init())
@@ -262,7 +263,7 @@ EIO_CTX *EIO_CTX_new()
 
 		i=GetLastError();
 		fprintf(stderr,"CreateWindow() error %ld\n",i);
-		free(ret);
+		Free(ret);
 		return(NULL);
 		}
 #else
