@@ -145,7 +145,7 @@ int port;
 	b.buffer_num_written=0;
 	b.buffer_num=0;
 	b.buffer_size=102400;
-	b.buffer=(char *)malloc(102400);
+	b.buffer=(char *)Malloc(102400);
 
 	ctx=EIO_CTX_new();
 
