@@ -368,7 +368,7 @@ bad:
 		
 		c=X509_NAME_oneline(req->req_info->subject);
 		fprintf(stderr,"subject=%s\n",c);
-		free(c);
+		Free(c);
 		if ((x=X509_new()) == NULL) goto end;
 		ci=x->cert_info;
 
@@ -433,7 +433,7 @@ bad:
 					goto end;
 					}
 				fprintf(stdout,"issuer= %s\n",str);
-				free(str);
+				Free(str);
 				}
 
 			if (subject == i) 
@@ -446,7 +446,7 @@ bad:
 					goto end;
 					}
 				fprintf(stdout,"subject=%s\n",str);
-				free(str);
+				Free(str);
 				}
 			if (serial == i)
 				{
@@ -508,7 +508,7 @@ bad:
 				unsigned char md[MD5_DIGEST_LENGTH];
 
 				n=i2d_X509(x,NULL);
-				p=(unsigned char *)malloc(n);
+				p=(unsigned char *)Malloc(n);
 				if (p == NULL)
 					{
 					fprintf(stderr,"out of memory\n");
@@ -657,7 +657,7 @@ int days;
 	BIGNUM *serial=NULL;
 	ASN1_INTEGER *bs=NULL,bs2;
 
-	buf=(char *)malloc(EVP_PKEY_size(pkey)*2+
+	buf=(char *)Malloc(EVP_PKEY_size(pkey)*2+
 		((serialfile == NULL)
 			?(strlen(CAfile)+strlen(POSTFIX)+1)
 			:(strlen(serialfile)))+1);
@@ -739,14 +739,14 @@ int days;
 
 	/* NOTE: this certificate can/should be self signed, unless it was
 	 * a certificate request in which case it is not. */
-	if (!reqfile && !X509_cert_verify(ctx,x,callb,NULL))
+	if (!reqfile && !X509_cert_verify(ctx,x,callb,NULL,NULL))
 		goto end;
 
 	X509_NAME_free(x->cert_info->issuer);
 	x->cert_info->issuer=X509_NAME_dup(xca->cert_info->subject);
 	if (x->cert_info->validity->notBefore != NULL)
-		free(x->cert_info->validity->notBefore);
-	if ((x->cert_info->validity->notBefore=(char *)malloc(100)) == NULL)
+		Free(x->cert_info->validity->notBefore);
+	if ((x->cert_info->validity->notBefore=(char *)Malloc(100)) == NULL)
 		goto end;
 	ASN1_INTEGER_free(x->cert_info->serialNumber);
 	x->cert_info->serialNumber=bs;
@@ -768,7 +768,7 @@ int days;
 		}
 	ret=1;
 end:
-	if (buf != NULL) free(buf);
+	if (buf != NULL) Free(buf);
 	if (bs != NULL) ASN1_INTEGER_free(bs);
 	if (io != NULL)	BIO_free(io);
 	if (serial != NULL) BN_free(serial);
@@ -795,7 +795,7 @@ int error;
 
 		s=X509_NAME_oneline(X509_get_subject_name(xs));
 		printf("%s\n",s);
-		free(s);
+		Free(s);
 		printf("error with certificate - error %d at depth %d\n%s\n",
 			error,depth,X509_cert_verify_error_string(error));
 		}
@@ -950,8 +950,8 @@ int days;
 
 	j=i2d_PublicKey(pkey,NULL);
 	if (x->cert_info->key->public_key->data != NULL)
-		free(x->cert_info->key->public_key->data);
-	p=x->cert_info->key->public_key->data=(unsigned char *)malloc(
+		Free(x->cert_info->key->public_key->data);
+	p=x->cert_info->key->public_key->data=(unsigned char *)Malloc(
 		(unsigned int)j+10);
 	if (p == NULL) { fprintf(stderr,"out of memory\n"); return(0); }
 	x->cert_info->key->public_key->length=j;
