@@ -118,7 +118,7 @@ long length;
 	i= *(p++);
 	if (len-- > 1) /* using one because of the bits left byte */
 		{
-		s=(unsigned char *)malloc((int)len);
+		s=(unsigned char *)Malloc((int)len);
 		if (s == NULL)
 			{
 			i=ERR_R_MALLOC_FAILURE;
@@ -132,7 +132,7 @@ long length;
 		s=NULL;
 
 	ret->length=(int)len;
-	if (ret->data != NULL) free(ret->data);
+	if (ret->data != NULL) Free((char *)ret->data);
 	ret->data=s;
 	ret->type=V_ASN1_BIT_STRING;
 	if (a != NULL) (*a)=ret;
@@ -150,7 +150,7 @@ int type;
 	{
 	ASN1_BIT_STRING *ret;
 
-	ret=(ASN1_BIT_STRING *)malloc(sizeof(ASN1_BIT_STRING));
+	ret=(ASN1_BIT_STRING *)Malloc(sizeof(ASN1_BIT_STRING));
 	if (ret == NULL)
 		{
 		ASN1err(ASN1_F_ASN1_BIT_STRING_TYPE_NEW,ERR_R_MALLOC_FAILURE);
@@ -166,8 +166,8 @@ void ASN1_BIT_STRING_free(a)
 ASN1_BIT_STRING *a;
 	{
 	if (a == NULL) return;
-	if (a->data != NULL) free(a->data);
-	free(a);
+	if (a->data != NULL) Free((char *)a->data);
+	Free((char *)a);
 	}
 
 int ASN1_BIT_STRING_cmp(a,b)
