@@ -115,5 +115,5 @@ ASN1_HEADER *a;
 	ASN1_OCTET_STRING_free(a->header);
 	if (a->meth != NULL)
 		a->meth->destroy(a->data);
-	free(a);
+	Free((char *)a);
 	}
