@@ -179,8 +179,8 @@ long length;
 		}
 	if ((ret->data == NULL) || (ret->length < len))
 		{
-		if (ret->data != NULL) free(ret->data);
-		ret->data=(unsigned char *)malloc((int)len);
+		if (ret->data != NULL) Free((char *)ret->data);
+		ret->data=(unsigned char *)Malloc((int)len);
 		if (ret->data == NULL)
 			{ i=ERR_R_MALLOC_FAILURE; goto err; }
 		}
@@ -205,7 +205,7 @@ ASN1_OBJECT *ASN1_OBJECT_new()
 	{
 	ASN1_OBJECT *ret;
 
-	ret=(ASN1_OBJECT *)malloc(sizeof(ASN1_OBJECT));
+	ret=(ASN1_OBJECT *)Malloc(sizeof(ASN1_OBJECT));
 	if (ret == NULL)
 		{
 		ASN1err(ASN1_F_ASN1_OBJECT_NEW,ERR_R_MALLOC_FAILURE);
@@ -224,7 +224,7 @@ void ASN1_OBJECT_free(a)
 ASN1_OBJECT *a;
 	{
 	if ((a == NULL) || !a->dynamic) return;
-	if (a->data != NULL) free(a->data);
-	free(a);
+	if (a->data != NULL) Free((char *)a->data);
+	Free((char *)a);
 	}
 
