@@ -146,7 +146,7 @@ int type;
 		}
 	if (len != 0)
 		{
-		s=(unsigned char *)malloc((int)len+1);
+		s=(unsigned char *)Malloc((int)len+1);
 		if (s == NULL)
 			{
 			i=ERR_R_MALLOC_FAILURE;
@@ -159,7 +159,7 @@ int type;
 	else
 		s=NULL;
 
-	if (ret->data != NULL) free(ret->data);
+	if (ret->data != NULL) Free((char *)ret->data);
 	ret->length=(int)len;
 	ret->data=s;
 	ret->type=tag;
