@@ -249,7 +249,7 @@ ASN1_TYPE *a;
 			break;
 			}
 		}
-	free((char *)a);
+	Free((char *)(char *)a);
 	}
 
 int i2d_ASN1_bytes(a, pp, tag, xclass)
@@ -307,8 +307,8 @@ int Pclass;
 		{
 		if (ret->length < len)
 			{
-			if (ret->data != NULL) free(ret->data);
-			s=(unsigned char *)malloc((int)len);
+			if (ret->data != NULL) Free((char *)ret->data);
+			s=(unsigned char *)Malloc((int)len);
 			if (s == NULL)
 				{
 				i=ERR_R_MALLOC_FAILURE;
@@ -323,7 +323,7 @@ int Pclass;
 	else
 		{
 		s=NULL;
-		if (ret->data != NULL) free(ret->data);
+		if (ret->data != NULL) Free((char *)ret->data);
 		}
 
 	ret->length=(int)len;
