@@ -143,15 +143,15 @@ int size;
 		if (num+i > slen)
 			{
 			if (s == NULL)
-				sp=(unsigned char *)malloc(
+				sp=(unsigned char *)Malloc(
 					(unsigned int)num+i*2);
 			else
-				sp=(unsigned char *)realloc(s,
+				sp=(unsigned char *)Realloc(s,
 					(unsigned int)num+i*2);
 			if (sp == NULL)
 				{
 				ASN1err(ASN1_F_A2I_ASN1_INTEGER,ERR_R_MALLOC_FAILURE);
-				if (s != NULL) free(s);
+				if (s != NULL) Free((char *)s);
 				goto err;
 				}
 			s=sp;
