@@ -114,6 +114,6 @@ PKCS7_DIGEST *a;
 	X509_ALGOR_free(a->md);
 	PKCS7_free(a->contents);
 	ASN1_OCTET_STRING_free(a->digest);
-	free(a);
+	Free((char *)a);
 	}
 
