@@ -150,7 +150,7 @@ long length;
 		{
 		if ((*a)->asn1 != NULL)
 			{
-			free((*a)->asn1);
+			Free((char *)(*a)->asn1);
 			(*a)->asn1=NULL;
 			}
 		(*a)->length=0;
@@ -233,7 +233,7 @@ PKCS7 *a;
 	{
 	if (a == NULL) return;
 
-	if (a->asn1 != NULL) free(a->asn1);
+	if (a->asn1 != NULL) Free((char *)a->asn1);
 
 	if (a->d.ptr != NULL)
 		{
@@ -266,6 +266,6 @@ PKCS7 *a;
 		}
 	if (a->type != NULL)
 		ASN1_OBJECT_free(a->type);
-	free((char *)a);
+	Free((char *)(char *)a);
 	}
 
