@@ -124,6 +124,6 @@ PKCS7_SIGNED *a;
 	sk_pop_free(a->cert,X509_free);
 	sk_pop_free(a->crl,X509_CRL_free);
 	sk_pop_free(a->signer_info,PKCS7_SIGNER_INFO_free);
-	free(a);
+	Free((char *)a);
 	}
 
