@@ -113,7 +113,7 @@ X509_REQ *x;
 	i=ri->pubkey->public_key->length;
 	d2i_RSAPublicKey(&rsa,(unsigned char **)&s,(long)i);
 	i=RSA_size(rsa);
-	m=s=(char *)malloc((unsigned int)i+10);
+	m=s=(char *)Malloc((unsigned int)i+10);
 	s[0]=0;
 	n=BN_bn2bin(rsa->n,(unsigned char *)&(s[1]));
 	if (s[1] & 0x80)
@@ -136,7 +136,7 @@ X509_REQ *x;
 		sprintf(str,"%02x%s",(unsigned char)s[i],((i+1) == n)?"":":");
 		if (BIO_puts(bp,str) <= 0) goto err;
 		}
-	free(m);
+	Free((char *)m);
 	if (BIO_puts(bp,"\n") <= 0) goto err;
 	neg=(rsa->e->neg)?"-":"";
 	
