@@ -102,7 +102,7 @@ X509_PUBKEY *a;
 	if (a == NULL) return;
 	X509_ALGOR_free(a->algor);
 	ASN1_BIT_STRING_free(a->public_key);
-	free(a);
+	Free((char *)a);
 	}
 
 
