@@ -109,7 +109,7 @@ NETSCAPE_SPKAC *a;
 	if (a == NULL) return;
 	X509_PUBKEY_free(a->pubkey);
 	ASN1_IA5STRING_free(a->challenge);
-	free(a);
+	Free((char *)a);
 	}
 
 int i2d_NETSCAPE_SPKI(a,pp)
@@ -165,6 +165,6 @@ NETSCAPE_SPKI *a;
 	NETSCAPE_SPKAC_free(a->spkac);
 	X509_ALGOR_free(a->sig_algor);
 	ASN1_BIT_STRING_free(a->signature);
-	free(a);
+	Free((char *)a);
 	}
 
