@@ -102,6 +102,6 @@ X509_VAL *a;
 	if (a == NULL) return;
 	ASN1_UTCTIME_free(a->notBefore);
 	ASN1_UTCTIME_free(a->notAfter);
-	free(a);
+	Free((char *)a);
 	}
 
