@@ -93,7 +93,7 @@ BN_CTX *ctx;
 	if (!BN_copy(r,a)) goto err;
 	n=mont->N;
 
-	if (!BN_copy(t1,r)) goto err;
+	if (!BN_copy(t1,a)) goto err;
 	BN_mask_bits(t1,mont->ri);
 
 	a=t1;
@@ -102,7 +102,7 @@ BN_CTX *ctx;
 	nl=n->top;
 	if ((al == 0) || (nl == 0)) { r->top=0; return(1); }
 
-	max=(nl+al+1); /* allow for overflow */
+	max=(nl+al+1); /* allow for overflow (no?) XXX */
 	if (bn_expand(r,(max)*BN_BITS2) == NULL) goto err;
 
 	r->neg=a->neg^n->neg;
@@ -111,8 +111,9 @@ BN_CTX *ctx;
 	rp=r->d;
 
 	/* clear the top bytes of T */
-	for (i=r->top; i<max; i++)
+	for (i=r->top; i<max; i++) /* memset? XXX */
 		r->d[i]=0;
+/*	memset(&(r->d[r->top]),0,(max-r->top)*sizeof(BN_ULONG)); */
 
 	r->top=max;
 	n0=mont->n0;
@@ -122,23 +123,27 @@ BN_CTX *ctx;
 		/* This is were part words probably goes wrong */
 		k=(rp[0]*n0)&BN_MASK2;
 		v=bn_mul_add_word(rp,np,nl,k);
-		if (v)
-			for (x=nl; v; x++)
-				{
-				v2=rp[x];
-				v2+=v;
-				rp[x]=v2;
-				v=(v2 < v)?1:0;
-				}
+		
+		for (x=nl; v; x++)
+			{
+			v2=rp[x];
+			v2+=v;
+			rp[x]=v2;
+			v=(v2 < v)?1:0;	/* ever true? XXX */
+			}
 		rp++;
 		}
 	while (r->d[r->top-1] == 0)
 		r->top--;
 
+/* fprintf(stderr,"top=%d new=%d\n",max,r->top); */
 	BN_rshift(ret,r,mont->ri);
 
 	if (BN_ucmp(ret,mont->N) >= 0)
-		bn_qsub(ret,ret,mont->N);
+		{
+/*		BN_sub(ret,ret,mont->N);   */
+		bn_qsub(ret,ret,mont->N); /* XXX */
+		}
 	retn=1;
 err:
 	return(retn);
@@ -179,12 +184,17 @@ BN_MONT_CTX *BN_MONT_CTX_new()
 	{
 	BN_MONT_CTX *ret;
 
-	if ((ret=(BN_MONT_CTX *)malloc(sizeof(BN_MONT_CTX))) == NULL)
+	if ((ret=(BN_MONT_CTX *)Malloc(sizeof(BN_MONT_CTX))) == NULL)
 		return(NULL);
 	ret->ri=0;
 	ret->RR=BN_new();
 	ret->N=BN_new();
 	ret->Ni=NULL;
+	if ((ret->RR == NULL) || (ret->N == NULL))
+		{
+		BN_MONT_CTX_free(ret);
+		return(NULL);
+		}
 	return(ret);
 	}
 
@@ -194,7 +204,7 @@ BN_MONT_CTX *mont;
 	if (mont->RR != NULL) BN_free(mont->RR);
 	if (mont->N != NULL) BN_free(mont->N);
 	if (mont->Ni != NULL) BN_free(mont->Ni);
-	free(mont);
+	Free(mont);
 	}
 
 int BN_MONT_CTX_set(mont,mod,ctx)
@@ -213,18 +223,26 @@ BN_CTX *ctx;
 
 #ifdef MONT_WORD
 {
-	int z;
+	BIGNUM tmod;
+	/* int z; */
 
 	BN_lshift(R,BN_value_one,BN_BITS2);		/* R */
-	z=mod->top;
-	mod->top=1;
-	Ri=BN_mod_inverse(R,mod,ctx);			/* Ri */
+	/* I was bad, this modification of a passed variable was
+	 * breaking the multithreaded stuff :-(
+	 * z=mod->top;
+	 * mod->top=1; */
+	tmod.d=mod->d;
+	tmod.top=1;
+	tmod.max=mod->max;
+	tmod.neg=mod->neg;
+
+	Ri=BN_mod_inverse(R,&tmod,ctx);			/* Ri */
 	BN_lshift(Ri,Ri,BN_BITS2);			/* R*Ri */
 	bn_qsub(Ri,Ri,BN_value_one);			/* R*Ri - 1 */
-	BN_div(Ri,NULL,Ri,mod,ctx);
+	BN_div(Ri,NULL,Ri,&tmod,ctx);
 	mont->n0=Ri->d[0];
 	BN_free(Ri);
-	mod->top=z;
+	/* mod->top=z; */
 }
 #else
 	BN_lshift(R,BN_value_one,mont->ri);		/* R */
