@@ -65,7 +65,7 @@ int bottom;
 	bit=(bits-1)%8;
 	mask=0xff<<bit;
 
-	buf=(unsigned char *)malloc(bytes);
+	buf=(unsigned char *)Malloc(bytes);
 	if (buf == NULL)
 		{
 		BNerr(BN_F_BN_RAND,ERR_R_MALLOC_FAILURE);
@@ -103,7 +103,7 @@ err:
 	if (buf != NULL)
 		{
 		memset(buf,0,bytes);
-		free(buf);
+		Free(buf);
 		}
 	return(ret);
 	}
