@@ -60,7 +60,7 @@ main()
 		{
 		ERR_load_crypto_strings();
 		printf("unable to load configuration, line %ld\n",eline);
-		ERR_print_errors(stderr);
+		ERR_print_errors_fp(stderr);
 		exit(1);
 		}
 	lh_stats(conf,stdout);
