@@ -1,5 +1,5 @@
-/* lib/des/des.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
+/* crypto/des/des.c */
+/* Copyright (C) 1995-1996 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
  * 
  * This file is part of an SSL implementation written
@@ -55,7 +55,7 @@
 #endif
 
 #include <time.h>
-#include "version.h"
+#include "des_ver.h"
 
 #ifdef VMS
 #include <types.h>
@@ -377,8 +377,8 @@ void doencryption()
 
 	if (buf == NULL)
 		{
-		if (    (( buf=(unsigned char *)malloc(BUFSIZE+8)) == NULL) ||
-			((obuf=(unsigned char *)malloc(BUFSIZE+8)) == NULL))
+		if (    (( buf=(unsigned char *)Malloc(BUFSIZE+8)) == NULL) ||
+			((obuf=(unsigned char *)Malloc(BUFSIZE+8)) == NULL))
 			{
 			fputs("Not enough memory\n",stderr);
 			Exit=10;
