@@ -66,17 +66,17 @@
 #define ITERATIONS 16
 #define HALF_ITERATIONS 8
 
-#define c2l(c,l)	(l =((unsigned long)(*((c)++)))    , \
-			 l|=((unsigned long)(*((c)++)))<< 8, \
-			 l|=((unsigned long)(*((c)++)))<<16, \
-			 l|=((unsigned long)(*((c)++)))<<24)
+#define c2l(c,l)	(l =((DES_LONG)(*((c)++)))    , \
+			 l|=((DES_LONG)(*((c)++)))<< 8, \
+			 l|=((DES_LONG)(*((c)++)))<<16, \
+			 l|=((DES_LONG)(*((c)++)))<<24)
 
 #define l2c(l,c)	(*((c)++)=(unsigned char)(((l)    )&0xff), \
 			 *((c)++)=(unsigned char)(((l)>> 8)&0xff), \
 			 *((c)++)=(unsigned char)(((l)>>16)&0xff), \
 			 *((c)++)=(unsigned char)(((l)>>24)&0xff))
 
-static const unsigned long des_SPtrans[8][64]={
+static const DES_LONG des_SPtrans[8][64]={
 {
 /* nibble 0 */
 0x00820200L, 0x00020000L, 0x80800000L, 0x80820200L,
@@ -221,7 +221,7 @@ static const unsigned long des_SPtrans[8][64]={
 0x00208000L, 0x00008020L, 0x08008020L, 0x08200000L,
 0x00000020L, 0x08208000L, 0x00208020L, 0x00000000L,
 0x08000000L, 0x08200020L, 0x00008000L, 0x00208020L}};
-static const unsigned long skb[8][64]={
+static const DES_LONG skb[8][64]={
 {
 /* for C bits (numbered as per FIPS 46) 1 2 3 4 5 6 */
 0x00000000L,0x00000010L,0x20000000L,0x20000010L,
@@ -379,8 +379,8 @@ static const unsigned long skb[8][64]={
 #endif 
 
 #ifndef NOPROTO
-static int body(unsigned long *out0, unsigned long *out1,
-	des_key_schedule ks, unsigned long Eswap0, unsigned long Eswap1);
+static int body(DES_LONG *out0, DES_LONG *out1,
+	des_key_schedule ks, DES_LONG Eswap0, DES_LONG Eswap1);
 #ifndef HEADER_DES_LOCL_H
 static int fcrypt_set_key(des_cblock (*key), des_key_schedule schedule);
 #endif
@@ -401,12 +401,12 @@ des_cblock (*key);
 des_key_schedule schedule;
 	{
 	static const int shifts2[16]={0,0,1,1,1,1,1,1,0,1,1,1,1,1,1,0};
-	register unsigned long c,d,t,s;
+	register DES_LONG c,d,t,s;
 	register unsigned char *in;
-	register unsigned long *k;
+	register DES_LONG *k;
 	register int i;
 
-	k=(unsigned long *)schedule;
+	k=(DES_LONG *)schedule;
 	in=(unsigned char *)key;
 
 	c2l(in,c);
@@ -536,7 +536,7 @@ static unsigned const char cov_2char[64]={
 
 #ifndef NOPROTO
 #ifdef PERL5
-char *des_crypt(char *buf,char *salt);
+char *des_crypt(const char *buf,char *salt);
 #else
 char *crypt(const char *buf,const char *salt);
 #endif
@@ -557,8 +557,8 @@ const char *buf;
 const char *salt;
 	{
 	unsigned int i,j,x,y;
-	unsigned long Eswap0,Eswap1;
-	unsigned long out[2],ll;
+	DES_LONG Eswap0,Eswap1;
+	DES_LONG out[2],ll;
 	des_cblock key;
 	des_key_schedule ks;
 	static unsigned char buff[20];
@@ -617,24 +617,24 @@ const char *salt;
 	}
 
 static int body(out0, out1, ks, Eswap0, Eswap1)
-unsigned long *out0;
-unsigned long *out1;
+DES_LONG *out0;
+DES_LONG *out1;
 des_key_schedule ks;
-unsigned long Eswap0;
-unsigned long Eswap1;
+DES_LONG Eswap0;
+DES_LONG Eswap1;
 	{
-	register unsigned long l,r,t,u;
+	register DES_LONG l,r,t,u;
 #ifdef DES_PTR
 	register unsigned char *des_SP=(unsigned char *)des_SPtrans;
 #endif
-	register unsigned long *s;
+	register DES_LONG *s;
 	register int i,j;
-	register unsigned long E0,E1;
+	register DES_LONG E0,E1;
 
 	l=0;
 	r=0;
 
-	s=(unsigned long *)ks;
+	s=(DES_LONG *)ks;
 	E0=Eswap0;
 	E1=Eswap1;
 
