@@ -94,7 +94,7 @@ BIO *bi;
 	{
 	BIO_F_MD_CTX *ctx;
 
-	ctx=(BIO_F_MD_CTX *)malloc(sizeof(BIO_F_MD_CTX));
+	ctx=(BIO_F_MD_CTX *)Malloc(sizeof(BIO_F_MD_CTX));
 	if (ctx == NULL) return(0);
 
 	bi->init=0;
@@ -107,7 +107,7 @@ static int md_free(a)
 BIO *a;
 	{
 	if (a == NULL) return(0);
-	free(a->ptr);
+	Free(a->ptr);
 	a->ptr=NULL;
 	a->init=0;
 	a->flags=0;
