@@ -85,7 +85,8 @@ unsigned char *iv;
 		memcpy(&(ctx->c.rc2_cbc.oiv[0]),iv,8);
 	memcpy(&(ctx->c.rc2_cbc.iv[0]),&(ctx->c.rc2_cbc.oiv[0]),8);
 	if (key != NULL)
-		RC2_set_key(&(ctx->c.rc2_cbc.ks),EVP_RC2_KEY_SIZE,key);
+		RC2_set_key(&(ctx->c.rc2_cbc.ks),EVP_RC2_KEY_SIZE,key,
+			EVP_RC2_KEY_SIZE*8);
 	}
 
 static void rc2_cbc_cipher(ctx,out,in,inl)
