@@ -87,7 +87,8 @@ unsigned char *iv;
 		memcpy(&(ctx->c.rc2_cfb.oiv[0]),iv,8);
 	memcpy(&(ctx->c.rc2_cfb.iv[0]),&(ctx->c.rc2_cfb.oiv[0]),8);
 	if (key != NULL)
-		RC2_set_key(&(ctx->c.rc2_cfb.ks),RC2_KEY_LENGTH,key);
+		RC2_set_key(&(ctx->c.rc2_cfb.ks),EVP_RC2_KEY_SIZE,key,
+			EVP_RC2_KEY_SIZE*8);
 	}
 
 static void rc2_cfb_cipher(ctx,out,in,inl)
