@@ -69,7 +69,7 @@ EVP_PKEY *EVP_PKEY_new()
 	{
 	EVP_PKEY *ret;
 
-	ret=(EVP_PKEY *)malloc(sizeof(EVP_PKEY));
+	ret=(EVP_PKEY *)Malloc(sizeof(EVP_PKEY));
 	if (ret == NULL)
 		{
 		EVPerr(EVP_F_EVP_PKEY_NEW,ERR_R_MALLOC_FAILURE);
@@ -91,6 +91,13 @@ EVP_PKEY *x;
 
 	i=CRYPTO_add(&x->references,-1,CRYPTO_LOCK_EVP_PKEY);
 	if (i > 0) return;
+#ifdef REF_CHECK
+	if (i < 0)
+		{
+		fprintf(stderr,"EVP_PKEY_free, bad reference count\n");
+		abort();
+		}
+#endif
 
 	switch (x->type)
 		{
@@ -107,5 +114,5 @@ EVP_PKEY *x;
 		DH_free(x->pkey.dh);
 		break;
 		}
-	free((char *)x);
+	Free((char *)x);
 	}
