@@ -60,7 +60,7 @@ METHOD *meth;
 		METHerr(METH_F_METH_NEW,METH_R_NO_METH_STRUCTURE_PASSED);
 		goto err;
 		}
-	if ((ret=(METHOD_CTX *)malloc(sizeof(METHOD_CTX))) == NULL)
+	if ((ret=(METHOD_CTX *)Malloc(sizeof(METHOD_CTX))) == NULL)
 		{
 		METHerr(METH_F_METH_NEW,ERR_R_MALLOC_FAILURE);
 		goto err;
@@ -124,7 +124,7 @@ char **rp;
 	if (type == METH_FREE)
 		{
 		sk_free(ctx->args);
-		free(ctx);
+		Free(ctx);
 		}
 	return(ret);
 	}
