@@ -124,7 +124,7 @@ char **pnull;
 	METHOD_CTX *m;
 	X_STATE *s;
 
-	s=(X_STATE *)malloc(sizeof(X_STATE));
+	s=(X_STATE *)Malloc(sizeof(X_STATE));
 	if (s == NULL)
 		{
 		METHerr(METH_F_X509_METHOD_INIT,ERR_R_MALLOC_FAILURE);
@@ -135,7 +135,7 @@ char **pnull;
 		lh_new(X509_subject_name_hash,X509_subject_name_cmp);
 	if (s->CA_by_name_cache == NULL)
 		{
-		free(s);
+		Free(s);
 		METHerr(METH_F_X509_METHOD_INIT,ERR_R_MALLOC_FAILURE);
 		return(-1);
 		}
