@@ -124,7 +124,7 @@
 #define Endian_Reverse32(a) \
 	{ \
 	unsigned long l=(a); \
-	((ROTATE(l,8)&0xFF00FF00)|(ROTATE(l,24)&0x00FF00FF)); \
+	(a)=((ROTATE(l,8)&0x00FF00FF)|(ROTATE(l,24)&0xFF00FF00)); \
 	}
 #else
 /* 6 instructions with rotate instruction, else 8 */
