@@ -99,6 +99,13 @@ typedef struct X509_name_entry_st
 
 #define X509_NAME	STACK /* of X509_NAME_ENTRY */
 
+typedef struct X509_extension_st
+	{
+	ASN1_OBJECT *object;
+	int critical;
+	ASN1_OCTET_STRING *value;
+	} X509_EXTENSION;
+
 typedef struct X509_req_info_st
 	{
 	ASN1_INTEGER *version;
@@ -126,9 +133,9 @@ typedef struct x509_cinf_st
 	X509_VAL *validity;
 	X509_NAME *subject;
 	X509_PUBKEY *key;
-	ASN1_BIT_STRING *issuerUID;	/* [ 1 ] optional in v2 */
-	ASN1_BIT_STRING *subjectUID;	/* [ 2 ] optional in v2 */
-	STACK *attributes;		/* [ 3 ] optional in v3 */
+	ASN1_BIT_STRING *issuerUID;		/* [ 1 ] optional in v2 */
+	ASN1_BIT_STRING *subjectUID;		/* [ 2 ] optional in v2 */
+	STACK /* X509_EXTENSION */ *extensions;	/* [ 3 ] optional in v3 */
 	} X509_CINF;
 
 typedef struct x509_st
@@ -143,16 +150,19 @@ typedef struct X509_revoked_st
 	{
 	ASN1_INTEGER *serialNumber;
 	ASN1_UTCTIME *revocationDate;
-	int sequence; /* loaded sequence */
+	STACK /* optional X509_EXTENSION */ *extensions;
+	int sequence; /* load sequence */
 	} X509_REVOKED;
 
 typedef struct X509_crl_info_st
 	{
+	ASN1_INTEGER *version;
 	X509_ALGOR *sig_alg;
 	X509_NAME *issuer;
 	ASN1_UTCTIME *lastUpdate;
 	ASN1_UTCTIME *nextUpdate;
 	STACK /* X509_REVOKED */ *revoked;
+	STACK /* [0] X509_EXTENSION */ *extensions;
 	} X509_CRL_INFO;
 
 typedef struct X509_crl_st
@@ -297,35 +307,35 @@ typedef struct X509_AUTH_st
 #define	VERIFY_ERR_OUT_OF_MEM				22
 #define	VERIFY_ERR_DEPTH_ZERO_SELF_SIGNED_CERT		23
 
-#define X509_verify(a,r) ASN1_verify(i2d_X509_CINF,a->sig_alg,\
+#define X509_verify(a,r) ASN1_verify((int (*)())i2d_X509_CINF,a->sig_alg,\
 	a->signature,(char *)a->cert_info,r)
 
-#define X509_REQ_verify(a,r) ASN1_verify(i2d_X509_REQ_INFO,a->sig_alg,\
-	a->signature,(char *)a->req_info,r)
+#define X509_REQ_verify(a,r) ASN1_verify((int (*)())i2d_X509_REQ_INFO, \
+	a->sig_alg,a->signature,(char *)a->req_info,r)
 
-#define X509_CRL_verify(a,r) ASN1_verify(i2d_X509_CRL_INFO,a->sig_alg,\
-	a->signature,(char *)a->crl,r)
+#define X509_CRL_verify(a,r) ASN1_verify((int (*)())i2d_X509_CRL_INFO, \
+	a->sig_alg, a->signature,(char *)a->crl,r)
 
-#define NETSCAPE_SPKI_verify(a,r) ASN1_sign(i2d_NETSCAPE_SPKAC,a->sig_algor,\
-		a->signature, (char *)a->spkac,r)
+#define NETSCAPE_SPKI_verify(a,r) ASN1_verify((int (*)())i2d_NETSCAPE_SPKAC, \
+		a->sig_algor,a->signature, (char *)a->spkac,r)
 
 #define X509_sign(x,pkey,md) \
-	ASN1_sign(i2d_X509_CINF, x->cert_info->signature, x->sig_alg, \
-		x->signature, (char *)x->cert_info,pkey,md)
+	ASN1_sign((int (*)())i2d_X509_CINF, x->cert_info->signature, \
+		x->sig_alg, x->signature, (char *)x->cert_info,pkey,md)
 
 #define X509_REQ_sign(x,pkey,md) \
-	ASN1_sign(i2d_X509_REQ_INFO,x->sig_alg, NULL, \
+	ASN1_sign((int (*)())i2d_X509_REQ_INFO,x->sig_alg, NULL, \
 		x->signature, (char *)x->req_info,pkey,md)
 
 #define X509_CRL_sign(x,pkey,md) \
-	ASN1_sign(i2d_X509_CRL_INFO,x->crl->sig_alg,x->sig_alg, \
+	ASN1_sign((int (*)())i2d_X509_CRL_INFO,x->crl->sig_alg,x->sig_alg, \
 		x->signature, (char *)x->crl,pkey,md)
 
 #define NETSCAPE_SPKI_sign(x,pkey,md) \
-	ASN1_sign(i2d_NETSCAPE_SPKAC, x->sig_algor,NULL, \
+	ASN1_sign((int (*)())i2d_NETSCAPE_SPKAC, x->sig_algor,NULL, \
 		x->signature, (char *)x->spkac,pkey,md)
 
-#define X509_dup(x509) (X509 *)ASN1_dup(i2d_X509, \
+#define X509_dup(x509) (X509 *)ASN1_dup((int (*)())i2d_X509, \
 		(char *(*)())d2i_X509,(char *)x509)
 #define d2i_X509_fp(fp,x509) (X509 *)ASN1_d2i_fp((char *(*)())X509_new, \
 		(char *(*)())d2i_X509, (fp),(unsigned char **)(x509))
@@ -334,7 +344,7 @@ typedef struct X509_AUTH_st
 		(char *(*)())d2i_X509, (bp),(unsigned char **)(x509))
 #define i2d_X509_bio(bp,x509) ASN1_i2d_bio(i2d_X509,bp,(unsigned char *)x509)
 
-#define X509_CRL_dup(crl) (X509_CRL *)ASN1_dup(i2d_X509_CRL, \
+#define X509_CRL_dup(crl) (X509_CRL *)ASN1_dup((int (*)())i2d_X509_CRL, \
 		(char *(*)())d2i_X509_CRL,(char *)crl)
 #define d2i_X509_CRL_fp(fp,crl) (X509_CRL *)ASN1_d2i_fp((char *(*)()) \
 		X509_CRL_new,(char *(*)())d2i_X509_CRL, (fp),\
@@ -347,7 +357,7 @@ typedef struct X509_AUTH_st
 #define i2d_X509_CRL_bio(bp,crl) ASN1_i2d_bio(i2d_X509_CRL,bp,\
 		(unsigned char *)crl)
 
-#define PKCS7_dup(p7) (PKCS7 *)ASN1_dup(i2d_PKCS7, \
+#define PKCS7_dup(p7) (PKCS7 *)ASN1_dup((int (*)())i2d_PKCS7, \
 		(char *(*)())d2i_PKCS7,(char *)p7)
 #define d2i_PKCS7_fp(fp,p7) (PKCS7 *)ASN1_d2i_fp((char *(*)()) \
 		PKCS7_new,(char *(*)())d2i_PKCS7, (fp),\
@@ -360,7 +370,7 @@ typedef struct X509_AUTH_st
 #define i2d_PKCS7_bio(bp,p7) ASN1_i2d_bio(i2d_PKCS7,bp,\
 		(unsigned char *)p7)
 
-#define X509_REQ_dup(req) (X509_REQ *)ASN1_dup(i2d_X509_REQ, \
+#define X509_REQ_dup(req) (X509_REQ *)ASN1_dup((int (*)())i2d_X509_REQ, \
 		(char *(*)())d2i_X509_REQ,(char *)req)
 #define d2i_X509_REQ_fp(fp,req) (X509_REQ *)ASN1_d2i_fp((char *(*)())\
 		X509_REQ_new, (char *(*)())d2i_X509_REQ, (fp),\
@@ -373,9 +383,9 @@ typedef struct X509_AUTH_st
 #define i2d_X509_REQ_bio(bp,req) ASN1_i2d_bio(i2d_X509_REQ,bp,\
 		(unsigned char *)req)
 
-#define RSAPublicKey_dup(rsa) (RSA *)ASN1_dup(i2d_RSAPublikKey, \
+#define RSAPublicKey_dup(rsa) (RSA *)ASN1_dup((int (*)())i2d_RSAPublikKey, \
 		(char *(*)())d2i_RSAPublicKey,(char *)rsa)
-#define RSAPrivateKey_dup(rsa) (RSA *)ASN1_dup(i2d_RSAPrivateKey, \
+#define RSAPrivateKey_dup(rsa) (RSA *)ASN1_dup((int (*)())i2d_RSAPrivateKey, \
 		(char *(*)())d2i_RSAPrivateKey,(char *)rsa)
 #define d2i_RSAPrivateKey_fp(fp,rsa) (RSA *)ASN1_d2i_fp((char *(*)())\
 		RSA_new,(char *(*)())d2i_RSAPrivateKey, (fp), \
@@ -388,10 +398,11 @@ typedef struct X509_AUTH_st
 #define i2d_RSAPrivateKey_bio(bp,rsa) ASN1_i2d_bio(i2d_RSAPrivateKey,bp, \
 		(unsigned char *)rsa)
 
-#define X509_NAME_dup(xn) (X509_NAME *)ASN1_dup(i2d_X509_NAME, \
+#define X509_NAME_dup(xn) (X509_NAME *)ASN1_dup((int (*)())i2d_X509_NAME, \
 		(char *(*)())d2i_X509_NAME,(char *)xn)
 #define X509_NAME_ENTRY_dup(ne) (X509_NAME_ENTRY *)ASN1_dup( \
-		i2d_X509_NAME_ENTRY, (char *(*)())d2i_X509_NAME_ENTRY,\
+		(int (*)())i2d_X509_NAME_ENTRY, \
+		(char *(*)())d2i_X509_NAME_ENTRY,\
 		(char *)ne)
 
 #ifndef NOPROTO
@@ -415,7 +426,8 @@ char *		X509_get_default_cert_file_env(void );
 char *		X509_get_default_private_dir(void );
 X509_REQ *	X509_to_X509_REQ(X509 *x, EVP_PKEY *pkey);
 X509 *		X509_REQ_to_X509(X509_REQ *r, int days,EVP_PKEY *pkey);
-int		X509_cert_verify(CERTIFICATE_CTX *ctx,X509 *xs, int (*cb)()); 
+int		X509_cert_verify(CERTIFICATE_CTX *ctx,X509 *xs, int (*cb)(),
+			int *error,char *arg); 
 
 void ERR_load_X509_strings(void );
 
@@ -462,6 +474,12 @@ int		i2d_X509_ATTRIBUTE(X509_ATTRIBUTE *a,unsigned char **pp);
 X509_ATTRIBUTE *d2i_X509_ATTRIBUTE(X509_ATTRIBUTE **a,unsigned char **pp,
 			long length);
 
+X509_EXTENSION *X509_EXTENSION_new(void );
+void		X509_EXTENSION_free(X509_EXTENSION *a);
+int		i2d_X509_EXTENSION(X509_EXTENSION *a,unsigned char **pp);
+X509_EXTENSION *d2i_X509_EXTENSION(X509_EXTENSION **a,unsigned char **pp,
+			long length);
+
 X509_NAME_ENTRY *X509_NAME_ENTRY_new(void);
 void		X509_NAME_ENTRY_free(X509_NAME_ENTRY *a);
 int		i2d_X509_NAME_ENTRY(X509_NAME_ENTRY *a,unsigned char **pp);
@@ -613,6 +631,10 @@ X509_ATTRIBUTE *X509_ATTRIBUTE_new();
 void		X509_ATTRIBUTE_free();
 int		i2d_X509_ATTRIBUTE();
 X509_ATTRIBUTE *d2i_X509_ATTRIBUTE();
+X509_EXTENSION *X509_EXTENSION_new();
+void		X509_EXTENSION_free();
+int		i2d_X509_EXTENSION();
+X509_EXTENSION *d2i_X509_EXTENSION();
 X509_NAME_ENTRY *X509_NAME_ENTRY_new();
 void		X509_NAME_ENTRY_free();
 int		i2d_X509_NAME_ENTRY();
