@@ -67,8 +67,8 @@
 
 #ifndef NOPROTO
 static int verify(CERTIFICATE_CTX *c, X509 *xs, int (*cb)(), int depth,
-	int *error);
-static int null_callback(int e, X509 *a, X509 *b, int c, int d);
+	int *error,char *arg);
+static int null_callback(int e, X509 *a, X509 *b, int c, int d, char *arg);
 #else
 static int verify();
 static int null_callback();
@@ -78,7 +78,7 @@ static int null_callback();
 void RSA_print_bytes();
 #endif
 
-char *X509_version="X509 part of SSLeay 0.6.3 06-Aug-1996";
+char *X509_version="X509 part of SSLeay 0.6.4 30-Aug-1996";
 
 int X509_add_cert_file(ctx,file, type)
 CERTIFICATE_CTX *ctx;
@@ -188,9 +188,9 @@ int type;
 			if (ctx->num_dirs_alloced < (ctx->num_dirs+1))
 				{
 				ctx->num_dirs_alloced+=10;
-				pp=(char **)malloc(ctx->num_dirs_alloced*
+				pp=(char **)Malloc(ctx->num_dirs_alloced*
 					sizeof(char *));
-				ip=(int *)malloc(ctx->num_dirs_alloced*
+				ip=(int *)Malloc(ctx->num_dirs_alloced*
 					sizeof(int));
 				if ((pp == NULL) || (ip == NULL))
 					{
@@ -201,13 +201,15 @@ int type;
 					sizeof(char *));
 				memcpy(ip,ctx->dirs_type,(ctx->num_dirs_alloced-10)*
 					sizeof(int));
-				if (ctx->dirs != NULL) free(ctx->dirs);
-				if (ctx->dirs_type != NULL) free(ctx->dirs_type);
+				if (ctx->dirs != NULL)
+					Free((char *)ctx->dirs);
+				if (ctx->dirs_type != NULL)
+					Free((char *)ctx->dirs_type);
 				ctx->dirs=pp;
 				ctx->dirs_type=ip;
 				}
 			ctx->dirs_type[ctx->num_dirs]=type;
-			ctx->dirs[ctx->num_dirs]=(char *)malloc((unsigned int)len+1);
+			ctx->dirs[ctx->num_dirs]=(char *)Malloc((unsigned int)len+1);
 			if (ctx->dirs[ctx->num_dirs] == NULL) return(0);
 			strncpy(ctx->dirs[ctx->num_dirs],ss,(unsigned int)len);
 			ctx->dirs[ctx->num_dirs][len]='\0';
@@ -219,39 +221,42 @@ int type;
 	return(1);
 	}
 
-static int null_callback(e,a,b,c,d)
+static int null_callback(e,a,b,c,d,f)
 int e;
 X509 *a;
 X509 *b;
 int c;
 int d;
+char *f;
 	{
 #ifdef LINT
-	a=b; b=a; c=d; d=c;
+	a=b; b=a; c=d; d=c; f=NULL;
 #endif
 	return(e);
 	}
 
-int X509_cert_verify(ctx,xs, cb,error)
+int X509_cert_verify(ctx,xs, cb, error, arg)
 CERTIFICATE_CTX *ctx;
 X509 *xs;
 int (*cb)();
 int *error;
+char *arg;
 	{
 	int ret;
 
 	if (cb == NULL)
-		ret=verify(ctx,xs,null_callback,0,error);
-	else	ret=verify(ctx,xs,cb,0,error);
+		ret=verify(ctx,xs,null_callback,0,error,arg);
+	else	ret=verify(ctx,xs,cb,0,error,arg);
 	return(ret);
 	}
 
-static int verify(ctx,xs, cb, depth, error)
+static int verify(ctx,xs, cb, depth, error, arg)
 CERTIFICATE_CTX *ctx;
 X509 *xs;
 int (*cb)();
 int depth;
 int *error;
+char *arg;
 	{
 	X509 *xi=NULL;
 	BUF_MEM *buf=NULL;
@@ -265,12 +270,12 @@ int *error;
 			== 0) && (depth == 0))
 			{
 			reason=VERIFY_ERR_DEPTH_ZERO_SELF_SIGNED_CERT;
-			ret=(*cb)(0,xs,xi,depth,reason);
+			ret=(*cb)(0,xs,xi,depth,reason,arg);
 			}
 		else
 			{
 			reason=VERIFY_ERR_UNABLE_TO_GET_ISSUER;
-			ret=(*cb)(0,xs,xi,depth,reason);
+			ret=(*cb)(0,xs,xi,depth,reason,arg);
 			}
 		goto end;
 		}
@@ -278,52 +283,55 @@ int *error;
 	if ((pkey=X509_extract_key(xi)) == NULL)
 		{
 		reason=VERIFY_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY;
-		ret=(*cb)(0,xs,xi,depth,reason);
-		goto end;
+		ret=(*cb)(0,xs,xi,depth,reason,arg);
 		}
 
 	if (X509_verify(xs,pkey) <= 0)
 		{
 		reason=VERIFY_ERR_SIGNATURE_FAILURE;
-		ret=(*cb)(0,xs,xi,depth,reason);
-		goto end;
+		ret=(*cb)(0,xs,xi,depth,reason,arg);
+		if (!ret) goto end;
 		}
 
 	i=X509_cmp_current_time(xs->cert_info->validity->notBefore);
 	if (i == 0)
 		{
 		reason=VERIFY_ERR_ERROR_IN_NOT_BEFORE_FIELD;
-		ret=(*cb)(0,xs,xi,depth,reason);
-		goto end;
+		ret=(*cb)(0,xs,xi,depth,reason,arg);
+		if (!ret) goto end;
 		}
 	if (i > 0)
 		{
 		reason=VERIFY_ERR_CERT_NOT_YET_VALID;
-		ret=(*cb)(0,xs,xi,depth,reason);
-		goto end;
+		ret=(*cb)(0,xs,xi,depth,reason,arg);
+		if (!ret) goto end;
 		}
 
 	i=X509_cmp_current_time(xs->cert_info->validity->notAfter);
 	if (i == 0)
 		{
 		reason=VERIFY_ERR_ERROR_IN_NOT_AFTER_FIELD;
-		ret=((*cb)(0,xs,xi,depth,reason));
+		ret=((*cb)(0,xs,xi,depth,reason,arg));
+		if (!ret) goto end;
 		}
-	else if (i < 0)
+
+	if (i < 0)
 		{
 		reason=VERIFY_ERR_CERT_HAS_EXPIRED;
-		ret=(*cb)(0,xs,xi,depth,reason);
+		ret=(*cb)(0,xs,xi,depth,reason,arg);
+		if (!ret) goto end;
 		}
-	else if (X509_name_cmp(xs->cert_info->subject,xs->cert_info->issuer)
+
+	if (X509_name_cmp(xs->cert_info->subject,xs->cert_info->issuer)
 		!= 0)
 		{
 		/* say this one is ok and check the parent */
 		reason=VERIFY_OK;
-		i=(*cb)(1,xs,xi,depth,reason);
+		i=(*cb)(1,xs,xi,depth,reason,arg);
 		if (!i)
 			ret=0;
 		else
-			ret=verify(ctx,xi,cb,depth+1,error);
+			ret=verify(ctx,xi,cb,depth+1,error,arg);
 		}
 	else
 		{
@@ -332,13 +340,13 @@ int *error;
 		if (depth == 0)
 			{
 			reason=VERIFY_ERR_DEPTH_ZERO_SELF_SIGNED_CERT;
-			ret=(*cb)(0,xs,xi,depth,reason);
+			ret=(*cb)(0,xs,xi,depth,reason,arg);
 			}
 		else
 			{
 			/* self signed CA, we are happy with this */
 			reason=VERIFY_ROOT_OK;
-			ret=(*cb)(1,xs,xi,depth,reason);
+			ret=(*cb)(1,xs,xi,depth,reason,arg);
 			}
 		}
 end:
@@ -415,6 +423,8 @@ int n;
 		{
 	case VERIFY_OK:
 		return("ok");
+	case VERIFY_ROOT_OK:
+		return("ok");
 	case VERIFY_ERR_UNABLE_TO_GET_ISSUER:
 		return("unable to get issuer certificate");
 	case VERIFY_ERR_UNABLE_TO_DECRYPT_SIGNATURE:
