@@ -58,11 +58,23 @@
 
 #include "err.h"
 
+#ifdef NO_MD2
+#include <md2.h>
+#else
 #include "md2.h"
+#endif
+#ifdef NO_MD5
+#include <md5.h>
+#else
 #include "md5.h"
+#endif
 #include "sha.h"
 
+#ifdef NO_DES
+#include <des.h>
+#else
 #include "des.h"
+#endif
 #include "rc2.h"
 #include "rc4.h"
 #include "idea.h"
