@@ -73,7 +73,7 @@ SSL_SESSION *in;
 unsigned char **pp;
 	{
 #define LSIZE2 (sizeof(long)*2)
-	int v1,v2,v3;
+	int v1=0,v2=0,v3=0;
 	unsigned char buf[4],ibuf1[LSIZE2],ibuf2[LSIZE2];
 	unsigned char ibuf3[LSIZE2],ibuf4[LSIZE2];
 	SSL_SESSION_ASN1 a;
@@ -84,7 +84,7 @@ unsigned char **pp;
 
 	/* Note that I cheat in the following 2 assignments.  I know
 	 * that if the ASN1_INTERGER passed to ASN1_INTEGER_set
-	 * is > sizeof(long)+1, the buffer will not be re-malloc()ed.
+	 * is > sizeof(long)+1, the buffer will not be re-Malloc()ed.
 	 * This is a bit evil but makes things simple, no dynamic allocation
 	 * to clean up :-) */
 	a.version.length=LSIZE2;
@@ -184,13 +184,13 @@ long length;
 
 	ai.data=NULL; ai.length=0;
 	M_ASN1_D2I_get(aip,d2i_ASN1_INTEGER);
-	version=ASN1_INTEGER_get(aip);
-	if (ai.data != NULL) { free(ai.data); ai.data=NULL; ai.length=0; }
+	version=(int)ASN1_INTEGER_get(aip);
+	if (ai.data != NULL) { Free(ai.data); ai.data=NULL; ai.length=0; }
 
 	/* we don't care about the version right now :-) */
 	M_ASN1_D2I_get(aip,d2i_ASN1_INTEGER);
-	ssl_version=ASN1_INTEGER_get(aip);
-	if (ai.data != NULL) { free(ai.data); ai.data=NULL; ai.length=0; }
+	ssl_version=(int)ASN1_INTEGER_get(aip);
+	if (ai.data != NULL) { Free(ai.data); ai.data=NULL; ai.length=0; }
 
 	os.data=NULL; os.length=0;
 	M_ASN1_D2I_get(osp,d2i_ASN1_OCTET_STRING);
@@ -206,7 +206,7 @@ long length;
                         SSL_NUM_CIPHERS,sizeof(CIPHER),(int (*)())ssl_cipher_cmp);
 	if (cp == NULL)
 		{
-		free(os.data);
+		Free(os.data);
 		c.error=SSL_R_UNSUPORTED_CIPHER;
 		goto err;
 		}
@@ -219,19 +219,19 @@ long length;
 
 	M_ASN1_D2I_get(osp,d2i_ASN1_OCTET_STRING);
 	ret->session_id_length=os.length;
-	if (ret->session_id != NULL) free(ret->session_id);
+	if (ret->session_id != NULL) Free(ret->session_id);
 	ret->session_id=os.data;
 	os.data=NULL; os.length=0;
 
 	M_ASN1_D2I_get(osp,d2i_ASN1_OCTET_STRING);
 	ret->master_key_length=os.length;
-	if (ret->master_key != NULL) free(ret->master_key);
+	if (ret->master_key != NULL) Free(ret->master_key);
 	ret->master_key=os.data;
 	os.data=NULL; os.length=0;
 
 	M_ASN1_D2I_get_IMP_opt(osp,d2i_ASN1_OCTET_STRING,0,V_ASN1_OCTET_STRING);
 	ret->key_arg_length=os.length;
-	if (ret->key_arg != NULL) free(ret->key_arg);
+	if (ret->key_arg != NULL) Free(ret->key_arg);
 	ret->key_arg=os.data;
 	os.data=NULL; os.length=0;
 
@@ -239,7 +239,7 @@ long length;
 	if (ai.data != NULL)
 		{
 		ret->time=ASN1_INTEGER_get(aip);
-		free(ai.data); ai.data=NULL; ai.length=0;
+		Free(ai.data); ai.data=NULL; ai.length=0;
 		}
 	else
 		ret->time=time(NULL);
@@ -248,7 +248,7 @@ long length;
 	if (ai.data != NULL)
 		{
 		ret->timeout=ASN1_INTEGER_get(aip);
-		free(ai.data); ai.data=NULL; ai.length=0;
+		Free(ai.data); ai.data=NULL; ai.length=0;
 		}
 	else
 		ret->timeout=100;
