@@ -90,7 +90,7 @@ SSL_CTX *SSL_CTX_new()
 	{
 	SSL_CTX *ret;
 	
-	ret=(SSL_CTX *)malloc(sizeof(SSL_CTX));
+	ret=(SSL_CTX *)Malloc(sizeof(SSL_CTX));
 	if (ret == NULL) goto err;
 
 	ret->num_cipher_list=0;
@@ -153,6 +153,13 @@ SSL_CTX *a;
 
 	i=CRYPTO_add(&a->references,-1,CRYPTO_LOCK_SSL_CTX);
 	if (i > 0) return;
+#ifdef REF_CHECK
+	if (i < 0)
+		{
+		fprintf(stderr,"SSL_CTX_free, bad reference count\n");
+		abort();
+		}
+#endif
 
 	if (a->sessions != NULL)
 		{
@@ -163,12 +170,12 @@ SSL_CTX *a;
 		CERTIFICATE_CTX_free(a->cert);
 	if (a->cipher_list != NULL)
 		{
-		free(a->cipher_list[0]);
-		free(a->cipher_list);
+		Free((char *)a->cipher_list[0]);
+		Free((char *)a->cipher_list);
 		}
 	if (a->default_cert != NULL)
 		ssl_cert_free(a->default_cert);
-	free(a);
+	Free((char *)a);
 	}
 
 void SSL_CTX_set_default_passwd_cb(ctx,cb)
@@ -187,7 +194,7 @@ char *arg;
 	ctx->app_verify_arg=arg;
 	}
 
-void SSL_CTX_set_default_verify(ctx,mode,cb)
+void SSL_CTX_set_verify(ctx,mode,cb)
 SSL_CTX *ctx;
 int mode;
 int (*cb)();
