@@ -54,7 +54,7 @@ CERT *ssl_cert_new()
 	{
 	CERT *ret;
 
-	ret=(CERT *)malloc(sizeof(CERT));
+	ret=(CERT *)Malloc(sizeof(CERT));
 	if (ret == NULL)
 		{
 		SSLerr(SSL_F_SSL_CERT_NEW,ERR_R_MALLOC_FAILURE);
@@ -77,11 +77,18 @@ CERT *c;
 
 	i=CRYPTO_add(&c->references,-1,CRYPTO_LOCK_SSL_CERT);
 	if (i > 0) return;
+#ifdef REF_CHECK
+	if (i < 0)
+		{
+		fprintf(stderr,"ssl_cert_free, bad reference count\n");
+		abort();
+		}
+#endif
 
 	if (c->x509 != NULL) X509_free(c->x509);
 	if (c->privatekey != NULL) EVP_PKEY_free(c->privatekey);
 	if (c->publickey != NULL) EVP_PKEY_free(c->publickey);
-	free(c);
+	Free(c);
 	}
 
 /* loads in the certificate from the server */
@@ -108,7 +115,7 @@ unsigned char *data;
 		i=s->ctx->app_verify_callback(s->ctx->app_verify_arg,s,x509);
 	else
 		i=X509_cert_verify(s->ctx->cert,x509,s->verify_callback,
-			&s->verify_result);
+			&s->verify_result,(char *)s);
 		
 	if ((s->verify_mode != SSL_VERIFY_NONE) && (!i))
 		{
