@@ -125,9 +125,9 @@ SSL *s;
 				ret= -1;
 				goto end;
 				}
-			if (s->init_buf) free(s->init_buf);
+			if (s->init_buf) Free((char *)s->init_buf);
 			s->init_buf=(unsigned char *)buf->data;
-			free(buf);
+			Free((char *)buf);
 			s->init_num=0;
 			s->state=SSL_ST_SEND_CLIENT_HELLO_A;
 			s->ctx->sess_connect++;
@@ -211,10 +211,10 @@ SSL *s;
 			break;
 
 		case SSL_ST_OK:
-			free(s->init_buf);
+			Free(s->init_buf);
 			s->init_buf=NULL;
 			s->init_num=0;
-			ERR_clear_error();
+		/*	ERR_clear_error();*/
 
 			/* If we want to cache session-ids in the client
 			 * and we sucessfully add the session-id to the
@@ -228,16 +228,16 @@ SSL *s;
 				CRYPTO_add(&s->session->references,1,
 					CRYPTO_LOCK_SSL_SESSION);
 
-				if (!s->ctx->new_session_cb(s->session))
+				if (!s->ctx->new_session_cb(s,s->session))
 					{
 					SSL_SESSION_free(s->session);
 					}
 				}
 
-			/* auto flush every 32 connections */
+			/* auto flush every 255 connections */
 			if ((!(s->ctx->session_cache_mode &
 				SSL_SESS_CACHE_NO_AUTO_CLEAR)) &&
-				((s->ctx->sess_accept_good & 0x1f) == 0x1f))
+				((s->ctx->sess_accept_good & 0xff) == 0))
 				SSL_flush_sessions(s->ctx,time(NULL));
 
 			ret=1;
@@ -321,7 +321,7 @@ SSL *s;
 		}
 	else
 		{
-		if (s->session->session_id != NULL) free(s->session->session_id);
+		if (s->session->session_id != NULL) Free(s->session->session_id);
 		s->session->session_id=NULL;
 		s->session->session_id_length=0;
 
@@ -391,19 +391,17 @@ SSL *s;
 		X509_free(s->session->peer);
 
 	/* hmmm, can we have the problem of the other session with this
-	 * cert, free's it before we increment the reference count. */
-	CRYPTO_w_lock(CRYPTO_LOCK_SSL_SESSION);
+	 * cert, Free's it before we increment the reference count. */
 	CRYPTO_w_lock(CRYPTO_LOCK_X509);
 	s->session->peer=s->session->cert->x509;
 	s->session->peer->references++;
 	CRYPTO_w_unlock(CRYPTO_LOCK_X509);
-	CRYPTO_w_unlock(CRYPTO_LOCK_SSL_SESSION);
 
 	/* get conn_id */
 	if (s->conn_id_length != s->state_conn_id_length)
 		{
-		if (s->conn_id) free(s->conn_id);
-		s->conn_id=(unsigned char *)malloc(s->state_conn_id_length);
+		if (s->conn_id) Free(s->conn_id);
+		s->conn_id=(unsigned char *)Malloc(s->state_conn_id_length);
 		if (s->conn_id == NULL)
 			{
 			ssl_return_error(s);
@@ -469,7 +467,8 @@ SSL *s;
 
 		s->challenge_length=CHALLENGE_LENGTH;
 		s2n(CHALLENGE_LENGTH,p);		/* challenge length */
-		s->challenge=(unsigned char *)malloc(CHALLENGE_LENGTH);
+		if (s->challenge != NULL) Free(s->challenge);
+		s->challenge=(unsigned char *)Malloc(CHALLENGE_LENGTH);
 		if (s->challenge == NULL)
 			{
 			ssl_return_error(s);
@@ -515,7 +514,7 @@ SSL *s;
 		/* make a master key */
 		i=s->session->master_key_length=(unsigned char)
 			s->session->cipher->key_size;
-		s->session->master_key=(unsigned char *)malloc((unsigned int)i+1);
+		s->session->master_key=(unsigned char *)Malloc((unsigned int)i+1);
 		if (s->session->master_key == NULL)
 			{
 			ssl_return_error(s);
@@ -541,7 +540,7 @@ SSL *s;
 		else
 			{
 			s->session->key_arg=(unsigned char *)
-				malloc((unsigned int)i);
+				Malloc((unsigned int)i);
 			if (s->session->key_arg == NULL)
 				{
 				ssl_return_error(s);
@@ -830,9 +829,9 @@ SSL *s;
 				SSL_SESSION_ID_LENGTH))
 			{
 			if (s->session->session_id)
-				free(s->session->session_id);
+				Free(s->session->session_id);
 			s->session->session_id=(unsigned char *)
-				malloc(SSL_SESSION_ID_LENGTH);
+				Malloc(SSL_SESSION_ID_LENGTH);
 			if (s->session->session_id == NULL)
 				{
 				ssl_return_error(s);
