@@ -67,17 +67,19 @@ int client;
 	DES_CBC_STATE *ds;
 
 	if (s->crypt_state == NULL)
-		s->crypt_state=(char *)malloc(sizeof(DES_CBC_STATE));
-	if (s->crypt_state == NULL) goto err;
+		{
+		s->crypt_state=(char *)Malloc(sizeof(DES_CBC_STATE));
+		if (s->crypt_state == NULL) goto err;
+		}
 
 	ds=(DES_CBC_STATE *)s->crypt_state;
 
 	if (s->key_material != NULL)
 		{
 		memset(s->key_material,0,s->key_material_length);
-		free(s->key_material);
+		Free(s->key_material);
 		}
-	s->key_material=(unsigned char *)malloc(MD5_DIGEST_LENGTH);
+	s->key_material=(unsigned char *)Malloc(MD5_DIGEST_LENGTH);
 	if (s->key_material == NULL) goto err;
 	s->key_material_length=MD5_DIGEST_LENGTH;
 
@@ -160,16 +162,18 @@ int client;
 	DES_EDE3_CBC_STATE *ds;
 
 	if (s->crypt_state == NULL)
-		s->crypt_state=(char *)malloc(sizeof(DES_EDE3_CBC_STATE));
-	if (s->crypt_state == NULL) goto err;
+		{
+		s->crypt_state=(char *)Malloc(sizeof(DES_EDE3_CBC_STATE));
+		if (s->crypt_state == NULL) goto err;
+		}
 	ds=(DES_EDE3_CBC_STATE *)s->crypt_state;
 
 	if (s->key_material != NULL)
 		{
 		memset(s->key_material,0,s->key_material_length);
-		free(s->key_material);
+		Free(s->key_material);
 		}
-	s->key_material=(unsigned char *)malloc(MD5_DIGEST_LENGTH*3);
+	s->key_material=(unsigned char *)Malloc(MD5_DIGEST_LENGTH*3);
 	if (s->key_material == NULL) goto err;
 	s->key_material_length=MD5_DIGEST_LENGTH*3;
 
@@ -269,16 +273,18 @@ int client;
 	DES_CFB_STATE *ds;
 
 	if (s->crypt_state == NULL)
-		s->crypt_state=(char *)malloc(sizeof(DES_CFB_STATE));
-	if (s->crypt_state == NULL) goto err;
+		{
+		s->crypt_state=(char *)Malloc(sizeof(DES_CFB_STATE));
+		if (s->crypt_state == NULL) goto err;
+		}
 	ds=(DES_CFB_STATE *)s->crypt_state;
 
 	if (s->key_material != NULL)
 		{
 		memset(s->key_material,0,s->key_material_length);
-		free(s->key_material);
+		Free(s->key_material);
 		}
-	s->key_material=(unsigned char *)malloc(MD5_DIGEST_LENGTH);
+	s->key_material=(unsigned char *)Malloc(MD5_DIGEST_LENGTH);
 	if (s->key_material == NULL) goto err;
 	s->key_material_length=MD5_DIGEST_LENGTH;
 
