@@ -56,7 +56,7 @@ int client;
 	NULL_STATE *ns;
 
 	if (s->crypt_state == NULL)
-		s->crypt_state=(char *)malloc(sizeof(NULL_STATE));
+		s->crypt_state=(char *)Malloc(sizeof(NULL_STATE));
 	if (s->crypt_state == NULL)
 		goto err;
 	ns=(NULL_STATE *)s->crypt_state;
