@@ -65,16 +65,16 @@ int client;
 	RC2_CBC_STATE *ds;
 
 	if (s->crypt_state == NULL)
-		s->crypt_state=(char *)malloc(sizeof(RC2_CBC_STATE));
+		s->crypt_state=(char *)Malloc(sizeof(RC2_CBC_STATE));
 	if (s->crypt_state == NULL) goto err;
 	ds=(RC2_CBC_STATE *)s->crypt_state;
 
 	if (s->key_material != NULL)
 		{
 		memset(s->key_material,0,s->key_material_length);
-		free(s->key_material);
+		Free(s->key_material);
 		}
-	md5d1=s->key_material=(unsigned char *)malloc(MD5_DIGEST_LENGTH*2);
+	md5d1=s->key_material=(unsigned char *)Malloc(MD5_DIGEST_LENGTH*2);
 	if (s->key_material == NULL) goto err;
 	md5d2= &(s->key_material[MD5_DIGEST_LENGTH]);
 	s->key_material_length=MD5_DIGEST_LENGTH*2;
@@ -83,15 +83,15 @@ int client;
 
 	if (client)
 		{
-		RC2_set_key(&(ds->rc2_read_ks),16,md5d1);
-		RC2_set_key(&(ds->rc2_write_ks),16,md5d2);
+		RC2_set_key(&(ds->rc2_read_ks),16,md5d1,128);
+		RC2_set_key(&(ds->rc2_write_ks),16,md5d2,128);
 		s->read_key= md5d1;
 		s->write_key= md5d2;
 		}
 	else
 		{
-		RC2_set_key(&(ds->rc2_read_ks),16,md5d2);
-		RC2_set_key(&(ds->rc2_write_ks),16,md5d1);
+		RC2_set_key(&(ds->rc2_read_ks),16,md5d2,128);
+		RC2_set_key(&(ds->rc2_write_ks),16,md5d1,128);
 		s->read_key= md5d2;
 		s->write_key= md5d1;
 		}
