@@ -85,6 +85,7 @@ case SSL_ST_GET_CLIENT_MASTER_KEY_A: str="get client master key A"; break;
 case SSL_ST_GET_CLIENT_MASTER_KEY_B: str="get client master key B"; break;
 case SSL_ST_SEND_SERVER_VERIFY_A: str="send server verify A"; break;
 case SSL_ST_SEND_SERVER_VERIFY_B: str="send server verify B"; break;
+case SSL_ST_SEND_SERVER_VERIFY_C: str="send server verify C"; break;
 case SSL_ST_GET_CLIENT_FINISHED_A: str="get client finished A"; break;
 case SSL_ST_GET_CLIENT_FINISHED_B: str="get client finished B"; break;
 case SSL_ST_SEND_SERVER_FINISHED_A: str="send server finished A"; break;
@@ -151,6 +152,7 @@ case SSL_ST_GET_CLIENT_MASTER_KEY_A:	str="GCMKA"; break;
 case SSL_ST_GET_CLIENT_MASTER_KEY_B:	str="GCMKA"; break;
 case SSL_ST_SEND_SERVER_VERIFY_A:	str="SSV_A"; break;
 case SSL_ST_SEND_SERVER_VERIFY_B:	str="SSV_B"; break;
+case SSL_ST_SEND_SERVER_VERIFY_C:	str="SSV_C"; break;
 case SSL_ST_GET_CLIENT_FINISHED_A:	str="GCF_A"; break;
 case SSL_ST_GET_CLIENT_FINISHED_B:	str="GCF_B"; break;
 case SSL_ST_SEND_SERVER_FINISHED_A:	str="SSF_A"; break;
