@@ -108,7 +108,7 @@ sub do_lib_rule
 	($Name=$name) =~ tr/a-z/A-Z/;
 
 	$ret.="$target: \$(${Name}OBJ)\n";
-	$ret.="\t\$(RM) \$(O_$Name)\n";
+#	$ret.="\t\$(RM) \$(O_$Name)\n";
 
 	# Due to a pathetic line length limit, I unwrap the args.
 	local($lib_names)="";
